//-----------------------------------------------------------------------------
// Copyright (c) 2007 dhpoware. All Rights Reserved.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.
//-----------------------------------------------------------------------------

#if !defined(MESH_UTILS_H)
#define MESH_UTILS_H

#include <d3dx9.h>
#include <string>
#include <vector>

class Mesh
{
public:
    ID3DXMesh *pMesh;
    IDirect3DVertexDeclaration9 *pDeclaration;
    std::vector<D3DVERTEXELEMENT9> elements;
    std::vector<IDirect3DTexture9*> textures;
    std::vector<D3DMATERIAL9> materials;

    Mesh();
    ~Mesh();

    bool create(const char *pszFilename, IDirect3DDevice9 *pDevice);
    void destroy();

    int getElementOffsetByUsage(D3DDECLUSAGE usage) const;

    bool bounds(D3DXVECTOR3 *pCenter, float *pRadius);
    bool normalize(float scaleTo = 1.0f, bool center = true);
    bool rotate(float degrees, float x, float y, float z);
    bool scale(float scale, D3DXVECTOR3 *pOffset = 0);
};

#endif